@@ -6,6 +6,7 @@ import argparse
 import os
 import re
 import sys
+import atexit
 
 # Third party imports
 import tqdm
@@ -753,7 +754,7 @@ class Version(cli.CLI):
                 ('name', cpenv.__name__),
                 ('version', cpenv.__version__),
                 ('url', cpenv.__url__),
-                ('package', paths.normalize(os.path.dirname(cpenv.__file__))),
+                ('package', paths.parent(cpenv.__file__)),
                 ('path', api.get_module_paths()),
             ]
         ))
@@ -889,8 +890,16 @@ class CliReporter(Reporter):
             bar.close()
 
 
+def perform_self_version_check():
+    from . import _self_version_check
+    is_latest, current, latest = _self_version_check.is_latest_version()
+    if not is_latest:
+        _self_version_check.warn_newer_version_available(current, latest)
+
+
 def main():
-    cpenv.set_reporter(CliReporter)
+    atexit.register(perform_self_version_check)
+    cpenv.set_reporter(CliReporter())
     cli.run(CpenvCLI, sys.argv[1:])
 
 
