@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 # Standard library imports
+import os
 from json import dumps as json_dump
+from json import loads as json_load
 
 try:
     from urllib2 import urlopen, HTTPError, URLError
@@ -21,7 +23,7 @@ import ssl
 def get(url):
     '''Make a get request.'''
 
-    context = ssl.create_default_context(cafile=certifi.where())
+    context = ssl.create_default_context(cafile=ca_certs())
     response = urlopen(url, context=context)
     return response
 
@@ -29,4 +31,11 @@ def get(url):
 def json(response):
     '''Get dict from json response.'''
 
-    return json_dump(response.read())
+    return json_load(response.read().decode())
+
+
+def ca_certs():
+    '''Returns path to vendored certifi/cacert.pem.'''
+
+    package = os.path.dirname(__file__)
+    return os.path.join(package, 'vendor', 'certifi', 'cacert.pem')
